/*
    This file is part of libkabc.

    Copyright (c) 2003 Cornelius Schumacher <schumacher@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
#ifndef KABC_LOCKNULL_H
#define KABC_LOCKNULL_H

#include <qstring.h>

#include "lock.h"

namespace KABC {

/**
  This class provides a lock without actually locking. It can be constructed in
  two ways: One that let all locks succeed and one that let all locks fail.
*/
class KABC_EXPORT LockNull : public Lock
{
  public:
    LockNull( bool allowAccess );
    ~LockNull();

    bool lock();
    bool unlock();

    QString error() const;

  private:
    bool mAllowAccess;

    class Private;
    Private *d;
};

}

#endif
